@@ -5,7 +5,7 @@
 
 #define QT_FEATURE_pipewire_screencapture 1
 
-#define QT_FEATURE_alsa -1
+#define QT_FEATURE_alsa 1
 
 #define QT_FEATURE_avfoundation -1
 
@@ -13,17 +13,17 @@
 
 #define QT_FEATURE_videotoolbox -1
 
-#define QT_FEATURE_gstreamer 1
+#define QT_FEATURE_gstreamer -1
 
-#define QT_FEATURE_gstreamer_photography 1
+#define QT_FEATURE_gstreamer_photography -1
 
-#define QT_FEATURE_gstreamer_gl 1
+#define QT_FEATURE_gstreamer_gl -1
 
 #define QT_FEATURE_gstreamer_gl_wayland -1
 
-#define QT_FEATURE_gstreamer_gl_egl 1
+#define QT_FEATURE_gstreamer_gl_egl -1
 
-#define QT_FEATURE_gstreamer_gl_x11 1
+#define QT_FEATURE_gstreamer_gl_x11 -1
 
 #define QT_FEATURE_gpu_vivante -1
 
@@ -39,7 +39,7 @@
 
 #define QT_FEATURE_native_windows_backend -1
 
-#define QT_FEATURE_pulseaudio 1
+#define QT_FEATURE_pulseaudio -1
 
 #define QT_FEATURE_aaudio -1
 
